@@ -24,7 +24,7 @@ class Neural_Network:
     SIMPLEPYAI
     ----------
     Hey guy !
-    I'm 15 years frensh dev !
+    I'm 15 years and a frensh dev !
     I present you my project of neural network !
     Just for the credit : LeLaboDuGame on Twitch -> https://twitch.tv/LeLaboDuGame
     You can use this library on all your project !
